function [pos]=acc2pos(acc,dt,f_low)
%function [pos]=acc2pos(acc,dt,f_low)
%-----------------------------------------------------------------------------
% ACC2POS- Matlab script for calculation of displacement when 
%            accelerations are known timesseries. The calculation is 
%            done in the frequency domain by apllying fft.
%
% Input:     Measurement accelerations
%
%            acc            :   Accelerometer measurements of x-accele-
%                               rations at 1 locations on the riser.
%            dt             :   time increment
%            f_low          :   low-pass frequency 
% Output:    pos            :   Calculated displacments
%
% Rolf Baarholm, Marintek, 24.06.98
% June 2004, Trygve Kristiansen, Marintek
%-----------------------------------------------------------------------------
%
nsamples = length(acc(:,1));
domega = 2*pi/(dt*nsamples);      
acchat = fft(acc);

% Make frequency array:
Omega = zeros(nsamples,1);

% Create Omega:
if mod(nsamples,2)==0,
   nh = nsamples/2;
   Omega(1:nh+1) = domega*(0:nh);
   Omega(nh+2:nsamples) = domega*(-nh+1:-1);
else
   nh = (nsamples-1)/2;
   Omega(1:nh+1) = domega*(0:nh); 
   Omega(nh+2:nsamples) = domega*(-nh:-1);
end

% High-pass filter:
n_low=floor(2*pi*f_low/domega);
acchat(1:n_low)=0;
acchat(nsamples-n_low+1:nsamples)=0;

% Multiply by omega^2:
acchat(2:nsamples) = -acchat(2:nsamples) ./ Omega(2:nsamples).^2;

% Inverse Fourier transform:
pos = real(ifft(acchat));

% --- End of function ---







