function [f,FFT,IFFT] = mukFFT(time,x)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FFT - IFFT CHECK FOR FURTHER USE                                       %
% I    x = data time series vector                                        %
% I    time = time vector                                                 %
% O    f = frequency array (Hz)                                           %
% O    FFT = FFT of signal                                                %
% O    IFFT = generated time series vector                                %
% Created by : Muhammad Mukhlas, NTNU, 2017                               % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
nsamples = length(x(:,1)); N=nsamples;
dt=time(2)-time(1);
samp_freq=1/dt;
fnyq=samp_freq/2;                 % Nyquist frequency (Hz)
T=dt*(nsamples-1);                % Length of time history (s)
df = 1/T;                         % Frequency resolution / fundamental (Hz)
%% FFT & IFFT %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
FFT=fft(x,N);                                                             %
f=-fnyq:df:fnyq; f=f';                                                    %
FFT_a=abs(FFT(1:N/2+1));                                                  %
IFFT=ifft(FFT);                                                           %
f_a=samp_freq/2*linspace(0,1,N/2+1);                                      %
subplot(2,1,1)                                                            %
plot(f_a,FFT_a);                                                          %
title('Single-Sided Amplitude Spectrum (Before filtering)')               %
xlabel('Frequency (Hz)')                                                  %
ylabel('Magnitude')                                                       %
subplot(2,1,2)                                                            %
plot(time,IFFT,time,x);                                                   %
title('FFT <-> IFFT check')                                               %
xlabel('Time (s)')                                                        %
ylabel('Data')                                                            %
legend('IFFT','Original')                                                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end